@@ -1,4 +1,4 @@
-"Xarchie*archieHost:	archie.sura.net(1526)",
+"#include \"/etc/X11/xarchie/defaultserver\"",
 "Xarchie*searchType:	exact",
 "Xarchie*sortType:	name",
 "Xarchie*maxHits:	99",
