@@ -645,7 +645,8 @@ XtIntervalId *id;
     }
 
     if (retries-- > 0) {
-	timeout.tv_sec = CLIENT_DIRSRV_BACKOFF(timeout.tv_sec);
+	timeout.tv_sec = client_dirsrv_timeout = CLIENT_DIRSRV_BACKOFF(
+                client_dirsrv_timeout);
 #ifdef DEBUG
 	if (pfs_debug > 2) {
             fprintf(stderr,"Timed out.  Setting timeout to %d seconds.\n",
