@@ -41,6 +41,9 @@
  * 30 Jun 1993: Fixes for Encore Umax (used cpp symbol "umax" as a guess).
  * 24 Aug 1993: Allow 200 reply for CWD as well as 250.
  *              Non-blocking IO defs for NeXT.
+ *  5 Jul 1994: Fixed bug in CR stripping.
+ *              Hopefully improved size-of-file detection.
+ *              Non-blocking IO defs for Ultrix.
  */
 #include <stdio.h>
 #include <errno.h>
@@ -70,14 +73,17 @@ extern void sysError(/* str */);
  *   sgi   : From amoss@cs.huji.ac.il
  *   umax  : From Gerry.Tomlinson@newcastle.ac.uk
  *   NeXT  : From jk@zarniwoop.pc-labor.uni-bremen.de
+ *   ultrix: From hurmejw@pb.com from cmr@world.std.com
+ *   __clipper__: From mlcampb1@mikec.b30.ingr.com (Intergraph, apparently)
+ *   alliant : From rdr@gscs.com
  */
-#if defined(hp300) || defined(NeXT)
+#if defined(hp300) || defined(NeXT) || defined(alliant)
   /* Here's for BSD, maybe, but Sys5 can't tell this from EOF. */
 # include <fcntl.h>
 # define MAKE_NONBLOCKING(fd) fcntl(fd,F_SETFL,O_NDELAY)
 # define ITWOULDBLOCK EWOULDBLOCK
 #else
-#if defined(sgi)
+#if defined(sgi) || defined(ultrix) || defined(__clipper__)
 # include <fcntl.h>
 # define MAKE_NONBLOCKING(fd) fcntl(fd,F_SETFL,O_NONBLOCK)
 # define ITWOULDBLOCK EWOULDBLOCK
@@ -91,8 +97,8 @@ extern void sysError(/* str */);
 # define MAKE_NONBLOCKING(fd) fcntl(fd,F_SETFL,O_NONBLOCK)
 # define ITWOULDBLOCK EAGAIN
 #endif /* umax */
-#endif /* sgi */
-#endif /* hp300 */
+#endif /* sgi || ultrix || __clipper__ */
+#endif /* hp300 || NeXT || alliant */
 /*
  * Networking includes from Brendan Kehoe (dirsend.c)
  */
@@ -832,9 +838,12 @@ FtpContext *ftpc;
 	break;
       case FTPS_GETPUT:
 	if (FTP_REPLY_PRELIM(ftpc->retcode)) { /* dataconn ready */
+	    char *s;
 	    status0(ftpc->reply+4);
-	    if (sscanf(ftpc->reply,"%*[^(](%d bytes)",&(ftpc->this_size)) != 1)
-		ftpc->this_size = 0;
+	    if ((s=rindex(ftpc->reply,'('))) {
+		if (sscanf(s,"(%d",&(ftpc->this_size)) != 1)
+		    ftpc->this_size = 0;
+	    }
 	    if (ftpAcceptDataConn(ftpc) < 0) {		/*  local failure */
 		if (ftpc->port != -1) {			/*    give up */
 		    DEBUG1("ftpProcessReply: closing port %d\n",ftpc->port);
@@ -1225,8 +1234,11 @@ FtpContext *ftpc;
 	if (ftpc->type == TYPE_A && ftpc->stripcr) {
 	    DEBUG0("ftpReadData: stripping <CR>\n");
 	    for (s=t=buf,i=nread; i--; ++s) {
-		if (*s != '\r')
+		if (*s != '\r') {
 		    *t++ = *s;
+		} else {
+		    nread -= 1;
+		}
 	    }
 	}
 	/* Write locally */
