@@ -9,11 +9,15 @@
  * (c) if it succeeded, call gethostbyname() to "canonicalize"
  *     the name (many systems don't return a fully-qualified name,
  *     and getdomainname() is a loss.
+ *  5 Jul 1994: Give default for MAXHOSTNAMELEN.
  */
 #include <stdio.h>
 #include <netdb.h>
+#ifdef HAVE_SYS_PARAM_H
+# include <sys/param.h>
+#endif
 #ifndef MAXHOSTNAMELEN
-#include <sys/param.h>
+# define MAXHOSTNAMELEN 64
 #endif
 #include "sysdefs.h"
 #include "stringdefs.h"
